<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl

$register_text = array (

'registernewuser'	=>	'Rejestracja nowego użytkownika',
'requiredfields'=>	'Wymagane pola są oznaczone znakiem',
'username'	=>	'Nazwa',
'password'	=>	'Hasło',
'confirmpass'	=>	'Potwierdź hasło',
'realname'	=>	'Imię i nazwisko',
'emailaddress'	=>	'Adres e-mail',
'jabberid'	=>	'Jabber ID',
'notifications'	=>	'Powiadomienia',
'none'		=>	'Brak',
'email'		=>	'E-mail',
'jabber'	=>	'Jabber',
'note'		=>	'<b>Uwaga:</b>	Wybraną metodą otrzymasz kod potwierdzający.<br>JEŚLI PODASZ FAŁSZYWE DANE. NIE DOSTANIESZ KODU.',
'sendcode'	=>	'Wyślij kod!',
'entercode'	=>	'Twój kod potwierdzający wysłano wybraną metodą. Gdy nadejdzie, wpisz go poniżej. Podaj też swoje hasło.',
'confirmationcode'	=>	'Kod potwierdzający',
'registeraccount'=>	'Utwórz konto',
'registererror'	=>	'Upewnij się że wypełniłeś wszystkie wymagane pola i wskazałeś metodę komunikacji.',
'usernametaken'	=>	'Ta nazwa jest już zajęta. Wybierz inną.',
'goback'	=>	'Wróć i zrób to.',
'noticefrom'	=>	'Powiadomienie od',
'addressused'	=>	'Twój adres został użyty do utworzenia konta we Flyspray. Jeśli nie spodziewałeś(-aś) się tej wiadomości, zignoruj ją. Twój kod potwierdzający to:',

// Added in version 0.9.7
'badmagic'      =>      'Błędny kod! Wprowadź klucz przesłany w wiadomości.',

);
// vim:fenc=utf-8:enc=utf-8
?>
